@@ -40,7 +40,8 @@ arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
 arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,  [0]*arrDataLen, [0]*arrDataLen] #[0]=time [1]=X, [2]=Y
 arrDataTemp=[0, 0, 0] #[0]=unused, [1]=X, [2]=Y
 arrDataIndex=0
-
+arrLogFiles=[]
+arrLogFilesIndex=0
 
 ##Explanations of algorithm and array structure
 ## Array arrData
