@@ -116,19 +116,23 @@ def ShowCollectingWindow():
 def ShowLogWindow():
     global LogWindowGraph
     
-    data.logfilename = QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
-#    data.logfilename = data.logfolder+"atest.csv"
-    OpenLogFile()
-    ProcessData()
+    tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+    tmp2=tmp.split("/")
+    l=len(tmp2)
+    data.logfilename=tmp2[l-1]
     
-    LogWindow.UpdateScreen()
+#    OpenLogFile()
+#    ProcessData()
+    
+#    LogWindow.UpdateScreen()
 
     LogWindow.show()
     StartWindow.hide()
     
     LogWindowGraph = LogWindowCanvas()
-    data.Xscale=1 #default zoom level
-    LogWindowGraph.show()
+#    data.Xscale=1 #default zoom level
+#    LogWindowGraph.show()
+    ShowLogFile()
 
 
 
@@ -193,7 +197,8 @@ def StopMeasurement():
     global app
     print "Stop timers..."
     app.timer_GetData.stop()
-    StopLogfile()        
+    StopLogfile()       
+    CollectingWindow.UpdateScreenStop()
 
 
 
@@ -246,12 +251,12 @@ def showGraph(self):
         paint.drawRect(0,0,781,data.Ysize)           
 
         Xscale=data.arrXscale[data.Xscale]
-        print "Zoom level:",  data.Xscale
+#        print "Zoom level:",  data.Xscale
 
         x=data.arrDataIndex/Xscale
         if(x>775): 
             shift=(x-775)*Xscale
-            print "Curve too long,  dropping first",  shift,  "values"
+#            print "Curve too long,  dropping first",  shift,  "values"
         else: shift=0
             
         try:
@@ -331,19 +336,19 @@ def showGraph(self):
 ##                    1=10 sec
 #                    if((i-lastmove)>30*Xscale): color="#009100" #green
 #                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
-#                    time=(i-lastmove)*Xscale
-#                    print time,  30*Xscale
-#                    if(time>30): color="#009100" #green
-#                    elif(time>15): color="#005000" #dark green
+#                    t=(i-lastmove)*Xscale
+#                    print t,  30*Xscale
+#                    if(t>30): color="#009100" #green
+#                    elif(t>15): color="#005000" #dark green
 #                    else: color="#6D0000" #dark red 
 
                     x0=lastmove/Xscale+1
                     x1=i/Xscale-1
                     if(x0<x1):
-                        time=(x1-x0)*Xscale/6          
-                        print x0,  "<=>",  x1,  time,  Xscale
-                        if(time>30): color="#009100" #green
-                        elif(time>15): color="#005000" #dark green
+                        t=(x1-x0)*Xscale/6          
+#                        print x0,  "<=>",  x1,  t,  Xscale
+                        if(t>30): color="#009100" #green
+                        elif(t>15): color="#005000" #dark green
                         else: color="#6D0000" #dark red                         
                         paint.setBrush(QtGui.QColor(color))
                         paint.setPen(QtGui.QColor(color))
@@ -363,6 +368,30 @@ def DeleteLogFile():
     LogWindow.DeleteLogFile()
 
 
+def ShowLogFile():
+    OpenLogFile()
+    ProcessData()
+    LogWindow.UpdateScreen()
+    LogWindowGraph = LogWindowCanvas()
+    data.Xscale=1 #default zoom level
+    LogWindowGraph.show()
+
+###########################################################################
+# Load next  logfile
+###########################################################################
+def NextLogFile():
+    LoadFileList(+1)
+    ShowLogFile()
+
+
+###########################################################################
+# Load last logfile
+###########################################################################
+def LastLogFile():
+    LoadFileList(-1)
+    ShowLogFile()
+
+
 ###########################################################################
 # Close the window Notes
 ###########################################################################
@@ -412,11 +441,15 @@ class frmStartWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), ShowLogWindow)
 
     def UpdateScreenStart(self):
-        app_path=os.path.dirname(__file__)
-        file = open(app_path+"/version", 'r')
-        data.version = file.readline()
-        data.version=data.version[:-1]
-        data.build = file.readline()
+        try:   
+            app_path=os.path.dirname(__file__)
+            print "Application path:",  app_path
+            file = open(app_path+"/version", 'r')
+            data.version = file.readline()
+            data.version=data.version[:-1]
+            data.build = file.readline()
+        except:
+            print "Version file not found"
         self.ui.lblVersion.setText(data.version+"."+data.build)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(app_path+"/SleepAnalyser.png"))
 
@@ -439,6 +472,8 @@ class frmCollectingWindow(QtGui.QWidget):
         QtGui.QWidget.__init__(self, parent)
         self.ui = Ui_CollectingWindow()
         self.ui.setupUi(self)
+        
+        QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), StopMeasurement)
 
     def UpdateScreen(self):
 #            self.ui.lblXacc.setText(str(data.arrData[1][data.arrDataIndex]))
@@ -460,13 +495,18 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui.lblTrigger.setText(str(data.trigger))
         app_path=os.path.dirname(__file__)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(app_path+"/SleepAnalyser.png"))
+        
+        
+    def UpdateScreenStop(self):
+        self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Stopped)")
 
 
     def closeEvent(self, event):
         StopMeasurement()
         StartWindow.show()
 #        NoteWindow.show()
-        CollectingWindow.close()
+        CollectingWindow.close() 
+
 
    
    
@@ -489,7 +529,8 @@ class frmLogWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), LowerTrigger)
         QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), ZoomIn)
         QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), ZoomOut)
-#        QtCore.QObject.connect(self.ui.cZoom, QtCore.SIGNAL("clicked()"), Zoom)
+        QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), NextLogFile)
+        QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), LastLogFile)
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), DeleteLogFile)
 
 
@@ -504,9 +545,14 @@ class frmLogWindow(QtGui.QWidget):
         reply = QtGui.QMessageBox.question(self, 'Delete Logfile', "Are you sure you want to delete this Logfile?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
-            os.remove(data.logfilename)    
-            StartWindow.show()
-            LogWindow.hide()
+            os.remove(data.logfolder+data.logfilename)    
+#            StartWindow.show()
+#            LogWindow.hide()
+#            LoadFileList(+1)
+            #load next file in list
+            data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
+            data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
+            ShowLogFile()
 
 
 
