@@ -40,7 +40,7 @@ def StartLogfile():
     data.logfilename=data.logfolder+"SleepAnalyser_"+t+".csv"
     data.logfile = open(data.logfilename, 'w')
     print "Created logfile "+data.logfilename
-    t="Date/Time, AccX, AccY"
+    t="Date/Time, AccX, AccY, "
     d=strftime("%d-%b-%Y", data.StartTime)
     data.logfile.write(t+"IMEI: *"+ID+", SW version: "+data.version+", Date: " + d + \
             ", Sampling intervall: " + str(data.sampling )+" ms, value_smoothing: " + \
@@ -75,13 +75,34 @@ def StopLogfile():
 
 
 
+###########################################################################
+#  Load list of log files into array
+###########################################################################
+def LoadFileList(dir):
+    print "Load file list"
+    output = os.popen("cd "+data.logfolder+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
+    data.arrLogFiles=output.split("\n")
+    data.arrLogFiles.pop()
+    print data.arrLogFiles
+    if(data.logfilename>""):
+        print data.logfilename
+        data.arrLogFileIndex=0
+        for i in range(len(data.arrLogFiles)):
+            if(data.logfilename==data.arrLogFiles[i]): data.arrLogFileIndex=i
+            
+    data.arrLogFileIndex=(data.arrLogFileIndex+dir)  % len(data.arrLogFiles)
+    data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
+    OpenLogFile()
+
+
+
+
 
 ###########################################################################
 #  Load old log file  to read and visualise it
 ###########################################################################
 def OpenLogFile():    
-    file = open(data.logfilename, 'r')
-
+    file = open(data.logfolder+data.logfilename, 'r')
     data.arrDataIndex=0
     print "Open logfile",  data.logfilename
     try:
